Modulation
==========

Linear modulations
------------------

.. python-apigen-group:: modulation-linear

Continuous-phase modulations
----------------------------

.. python-apigen-group:: modulation-continuous-phase

Orthogonal modulations
----------------------

.. _pulse-shaping-functions:

Pulse shaping
-------------

.. python-apigen-group:: modulation-pulse-shaping

Symbol encoding
---------------

.. python-apigen-group:: modulation-symbol-encoding
